package ru.ulstu.tsMethods.exponential;

import ru.ulstu.models.Forecast;
import ru.ulstu.models.Model;
import ru.ulstu.models.TimeSeries;
import ru.ulstu.models.exceptions.ModelingException;
import ru.ulstu.tsMethods.TimeSeriesMethod;

import static ru.ulstu.tsMethods.exponential.ExponentialParamName.ALPHA;

public class NoTrendNoSeason extends TimeSeriesMethod {
    private ExponentialMethodParams exponentialMethodParams;

    public NoTrendNoSeason(ExponentialMethodParams exponentialMethodParams) {
        this.exponentialMethodParams = exponentialMethodParams;
    }

    @Override
    protected Model getModelOfValidTimeSeries(TimeSeries timeSeries) throws ModelingException {
        Model model = new Model(timeSeries);
        model.addValue(timeSeries.getFirstValue());
        //выполняется проход модели по сглаживанию
        for (int t = 1; t < timeSeries.getValues().size(); t++) {
            model.addValue(timeSeries.getValues().get(t),
                    (1 - exponentialMethodParams.getValue(ALPHA)) * timeSeries.getNumericValue(t)
                            + exponentialMethodParams.getValue(ALPHA) * model.getModelTimeSeries().getValues().get(t - 1).getValue());
        }
        return model;
    }

    @Override
    protected Forecast makeForecast(Forecast forecast) {
        forecast.getForecastTimeSeries()
                .getFirstValue()
                .setValue(forecast.getModel().getModelTimeSeries().getLastValue().getValue());
        for (int t = 1; t < forecast.getForecastTimeSeries().getLength(); t++) {
            forecast.getForecastTimeSeries()
                    .getValues()
                    .get(t)
                    .setValue(forecast.getForecastTimeSeries().getValues().get(t - 1).getValue());
        }
        return forecast;
    }
}
